==> react-molecule-stepper-2.0.0.tgz: package/lib/Stepper/Stepper.js <==
import PropTypes from 'prop-types';
import { naturalNumber } from '../prop-types.js';
import Step from '../Step/Step.js';
import { useStepsContext } from '../context/index.js';
import Children from '../Children.js';
import { jsx as _jsx } from "react/jsx-runtime";

var Stepper = function Stepper(_ref) {
  var children = _ref.children,
      stepsNumber = _ref.steps,
      currentStep = _ref.step,
      _ref$labels = _ref.labels,
      labels = _ref$labels === void 0 ? [] : _ref$labels;

  var _useStepsContext = useStepsContext(),
      design = _useStepsContext.design,
      alignment = _useStepsContext.alignment,
      icon = _useStepsContext.icon,
      visitedIcon = _useStepsContext.visitedIcon,
      currentIcon = _useStepsContext.currentIcon,
      onChange = _useStepsContext.onChange,
      hasConnector = _useStepsContext.hasConnector;

  if (children) return /*#__PURE__*/_jsx(Children, {
    steps: stepsNumber,
    step: currentStep,
    labels: labels,
    design: design,
    alignment: alignment,
    icon: icon,
    visitedIcon: visitedIcon,
    currentIcon: currentIcon,
    hasConnector: hasConnector,
    onChange: onChange,
    children: children
  });else if (stepsNumber === undefined) return null;
  return Array(Math.max(stepsNumber, labels.length)).fill().map(function (u, index) {
    return /*#__PURE__*/_jsx(Step, {
      steps: stepsNumber,
      step: index + 1,
      visited: index + 1 < currentStep,
      current: currentStep === index + 1,
      label: labels[index]
    }, index);
  });
};

Stepper.displayName = 'Stepper';
export default Stepper;

==> react-molecule-stepper-2.2.0.tgz: package/lib/Stepper/Stepper.js <==
import PropTypes from 'prop-types';
import Injector from '@s-ui/react-primitive-injector';
import { naturalNumber } from '../prop-types.js';
import Step from '../Step/Step.js';
import { useStepsContext } from '../context/index.js';
import { jsx as _jsx } from "react/jsx-runtime";

var Stepper = function Stepper(_ref) {
  var children = _ref.children,
      stepsNumber = _ref.steps,
      currentStep = _ref.step,
      _ref$labels = _ref.labels,
      labels = _ref$labels === void 0 ? [] : _ref$labels;

  var _useStepsContext = useStepsContext(),
      design = _useStepsContext.design,
      alignment = _useStepsContext.alignment,
      icon = _useStepsContext.icon,
      visitedIcon = _useStepsContext.visitedIcon,
      currentIcon = _useStepsContext.currentIcon,
      onChange = _useStepsContext.onChange,
      hasConnector = _useStepsContext.hasConnector;

  if (children) return /*#__PURE__*/_jsx(Injector, {
    steps: stepsNumber,
    step: currentStep,
    labels: labels,
    design: design,
    alignment: alignment,
    icon: icon,
    visitedIcon: visitedIcon,
    currentIcon: currentIcon,
    hasConnector: hasConnector,
    onChange: onChange,
    children: children
  });else if (stepsNumber === undefined) return null;
  return Array(Math.max(stepsNumber, labels.length)).fill().map(function (u, index) {
    return /*#__PURE__*/_jsx(Step, {
      steps: stepsNumber,
      step: index + 1,
      visited: index + 1 < currentStep,
      current: currentStep === index + 1,
      label: labels[index]
    }, index);
  });
};

Stepper.displayName = 'Stepper';
export default Stepper;
